@@ -4,22 +4,22 @@ use strict;
 use vars qw/$VERSION @ISA %authorname/;
 use DBIx::dbMan::Extension;
 
-$VERSION = '0.05';
+$VERSION = '0.06';
 @ISA = qw/DBIx::dbMan::Extension/;
 
 # registered authornames
 %authorname = (
-	'000001' => 'Ing. Milan Sorm <sorm@pef.mendelu.cz>',
+	'000001' => 'Mgr. Ing. Milan Sorm <sorm@pef.mendelu.cz>',
 	'000002' => 'Ing. Frantisek Darena <darena@pef.mendelu.cz>',
 	'000003' => 'Ales Kutin <kutin@pef.mendelu.cz>',
-	'000004' => 'Ondrej Kudlik <kudlik@pef.mendelu.cz>',
+	'000004' => 'Ondrej \'Kepi\' Kudlik <kudlik@pef.mendelu.cz>',
 );
 
 1;
 
-sub IDENTIFICATION { return "000001-000012-000005"; }
+sub IDENTIFICATION { return "000001-000012-000006"; }
 
-sub author { return 'Ing. Milan Sorm <sorm@pef.mendelu.cz>'; }
+sub author { return 'Mgr. Ing. Milan Sorm <sorm@pef.mendelu.cz>'; }
 
 sub preference { return 0; }
 
